@@ -38,7 +38,7 @@ def add_tasks_and_process_time_middleware(new_app):
             context = request.scope["aws.context"]
             context.serverless_sdk.set_endpoint(request.url.path)
         response = await call_next(request)
-        if response.status_code == 404 and g.settings.save_calls:
+        if response.status_code in [404, 405] and g.settings.save_calls:
             await save_not_found_from_request(request)
         response.headers["X-Tasks-Time"] = str(save_tasks())  # queue tasks
         response.headers["X-Process-Time"] = str(time.time() - start_time)
